#!/usr/bin/perl

use strict;
use warnings;

my (@X, @Y);

my ($dt, $dt_set) = (0.0, 0);

while (<STDIN>) {
    next if (/^\#/);
    my @toks = split;
    push @X, $toks[1];
    push @Y, $toks[2];
    if ($dt_set == 0) {
        $dt = $toks[0];
        $dt_set = 1;
    } elsif ($dt_set == 1) {
        $dt = $toks[0] - $dt;
        $dt_set = 2;
    }
}

print STDERR "<> scalar \@X = ", (scalar @X),
             "; scalar \@Y = ", (scalar @Y), " dt = $dt\n";

my $n_samples = scalar @X;
die unless $n_samples == scalar @Y;
die unless $n_samples > 0;

my ($meanX, $meanY) = (0.0, 0.0);
for (my $n = 0; $n < $n_samples; ++$n) {
    $meanX += $X[$n];
    $meanY += $Y[$n];
}

$meanX /= $n_samples;
$meanY /= $n_samples;

print STDERR "<> means = $meanX, $meanY\n";

my ($sigmaX, $sigmaY) = (0.0, 0.0);
for (my $n = 0; $n < $n_samples; ++$n) {
    $sigmaX += ($X[$n] - $meanX)*($X[$n] - $meanX);
    $sigmaY += ($Y[$n] - $meanY)*($Y[$n] - $meanY);
}

$sigmaX /= $n_samples - 1;
$sigmaY /= $n_samples - 1;

print STDERR "<> variances = ", sqrt($sigmaX), ", ", sqrt($sigmaY), "\n";

for (my $lag = 0; $lag < 10000; $lag += 10) {
    my ($accuX, $accuY) = (0.0, 0.0);
    for (my $t = 0; $t < $n_samples - $lag; ++$t) {
        $accuX += ($X[$t] - $meanX)*($X[$t + $lag] - $meanX);
        $accuY += ($Y[$t] - $meanY)*($Y[$t + $lag] - $meanY);
    }

    $accuX /= $sigmaX*($n_samples - $lag);
    $accuY /= $sigmaY*($n_samples - $lag);

    printf "%.1f $accuX $accuY\n", $lag*$dt;
}
